==> lib_rapid-0.0.16.crate: lib_rapid-0.0.16/readme.md <==
![](https://github.com/Pencilcaseman/librapid/blob/master/branding/logo_transparent_trimmed.png)
[![Discord](https://img.shields.io/discord/848914274105557043)](https://discord.gg/cGxTFTgCAC)
[![Crates.io](https://img.shields.io/crates/v/lib_rapid?color=green&style=plastic)](https://crates.io/crates/lib_rapid)
[![Docs.rs](https://img.shields.io/docsrs/lib_rapid?style=plastic)](https://docs.rs/crate/lib_rapid/)
----

LibRapid for Rust - Fast. Reliable. Lightweight.
============

Credits
-----

The original idea comes from Pencilcaseman, I collaborated with him to get LibRapid into Rust. We're closely working together to provide
the best possible user experience and consistency over all libraries.

Documentation
_____

Depending on the current published LibRapid version and how many crates are in queue on docs.rs, you may need to build the docs yourself.
To do that, simply git-clone this repository and then run `cargo doc`. After that, your documentation should be ready in src/target/doc/index.html.

How does it work?
-----

The Rust-port of LibRapid is a derivative from the main library made for C++ and Python. It's goal is to be optimized for speedy calculations, mathematical and
scientific applications.

Performance
-----

LibRapid for Rust is fully optimized - meaning your calculations for game scripts and maths will be faster as a result. All functions that are implemented bring new features to Rust, while being optimized for speed.

Maintainer
-----
The main maintainer of this repository is @NervousNullPtr. The secondary maintainer is @Pencilcaseman.

==> lib_rapid-0.0.17.crate: lib_rapid-0.0.17/readme.md <==
![](https://github.com/Pencilcaseman/librapid/blob/master/branding/logo_transparent_trimmed.png)
[![Discord](https://img.shields.io/discord/848914274105557043)](https://discord.gg/cGxTFTgCAC)
[![Crates.io](https://img.shields.io/crates/v/lib_rapid?color=green)](https://crates.io/crates/lib_rapid)
[![Docs.rs](https://img.shields.io/docsrs/lib_rapid)](https://docs.rs/crate/lib_rapid/)
----

LibRapid for Rust - Fast. Reliable. Lightweight.
============

Credits
-----

The original idea comes from Pencilcaseman, I collaborated with him to get LibRapid into Rust. We're closely working together to provide
the best possible user experience and consistency over all libraries.

Documentation
-----

Depending on the current published LibRapid version and how many crates are in queue on docs.rs, you may need to build the docs yourself.
To do that, simply git-clone this repository and then run `cargo doc`. After that, your documentation should be ready in src/target/doc/index.html.

How does it work?
-----

The Rust-port of LibRapid is a derivative from the main library made for C++ and Python. It's goal is to be optimized for speedy calculations, mathematical and
scientific applications.

Performance
-----

LibRapid for Rust is fully optimized - meaning your calculations for game scripts and maths will be faster as a result. All functions that are implemented bring new features to Rust, while being optimized for speed.

Maintainer
-----
The main maintainer of this repository is @NervousNullPtr. The secondary maintainer is @Pencilcaseman.
